@@ -47,19 +47,34 @@ function usage(){
 Usage:
     ops.sh COMMAND [arg [arg [...]]]
 
-Where COMMAND is one of:
-  build-venv   - Build the development environment.
-  rebuild-venv - Delete and reuild the development environment.
-  test                - Run tox testing (Note 1).
-  test-envs           - Run tox testing on specified environments (Note 2).
-  test-py-all         - Run tox testing on python unit test environments (Note 1).
-  test-style-quality  - Run tox testing on style and quality test environments (Note 1).
-  test-coverage       - Run tox testing on coverage test environment (Note 1).
-  unit-test           - Run unit testing directly in current environment (Note 3).
-  coverage            - Generate code coverage data (Note 3).
-  docs                - Generate documentation (Note 4,5)
-  quality             - Run code quality analysis (Note 4,6)
-  style               - Run code style analysis and tests (Note 6)
+Where COMMAND is one of the following:
+  Environment set-up commands
+    build-venv          - Build the development environment.
+    rebuild-venv        - Delete and reuild the development environment.
+
+  Documentation
+    docs                - Generate documentation (Note 4,5)
+
+  Unit testing and static analysis
+    unit-test           - Run unit testing directly in current environment (Note 3).
+    coverage            - Generate code coverage data (Note 3).
+    quality             - Run code quality analysis (Note 4,6)
+    style               - Run code style analysis and tests (Note 6)
+
+  Regression testing
+    test                - Run tox testing (Note 1).
+    test-envs           - Run tox testing on specified environments (Note 2).
+    test-py-all         - Run tox testing on python unit test environments (Note 1).
+    test-style-quality  - Run tox testing on style and quality test environments (Note 1).
+    test-coverage       - Run tox testing on coverage test environment (Note 1).
+
+  Release
+    prerelease-tests    - Run a quick set of tests required for release.
+    prerelease          - Ensure the working directory is clean, and run prerelease tests.
+    release-major       - Perform a release upgrading the major version of the repository.
+    release-minor       - Perform a release upgrading the minor version of the repository.
+    release-patch       - Perform a release upgrading the patch version of the repository.
+
   -h|--help|help      - Display this help and exit.
 
 Notes:
@@ -126,7 +141,7 @@ function do_action(){
 
     test-py-all)
       shift
-      tox -vv "$@" -e py36,py37,py38,py39
+      tox -vv "$@" -e py37,py38,py39,py310,py311
     ;;
 
     test-style-quality)
@@ -183,7 +198,7 @@ function do_action(){
       shift
       activate_venv
       export PYTHONUNBUFFERED=yes
-      run "Check Source code Style Compliance" flake8 --max-line-length=120 --ignore=E201,E202,E401,E221,E241,E251,W504 --exclude '__pending*' ./ptutils
+      run "Check Source code Style Compliance" flake8 --max-line-length=120 --ignore=E201,E202,E401,E221,E241,E251,E271,W504,E272 --exclude '__pending*' ./ptutils
     ;;
     -h|--help|help)
       usage
@@ -224,7 +239,7 @@ function do_action(){
     ;;
 
     clean)
-        run "Removing built files but preserving venv" git clean -xdf -e py3venv/ -e op.log
+        run "Removing built files but preserving venv" git clean -xdf -e '*venv*/' -e op.log
     ;;
 
     clean-all)
