@@ -8,10 +8,12 @@
 # Main imports
 # ------------------------------------------------------------------------------------------------------------------------
 import datetime
+from io import FileIO
 import json
 import os
 from types import ModuleType
-from typing import Any, Union, IO
+from typing import Any, Callable, Union, IO, Optional, Pattern
+from ptutils.typing import is_mapping, is_sequence
 
 # ------------------------------------------------------------------------------------------------------------------------
 # Import checks
@@ -22,6 +24,12 @@ try:
 except ImportError:  # pragma: no cover
     HAVE_YAML = False
 
+if HAVE_YAML:
+    try:
+        from yaml import CLoader as YamlLoader, CDumper as YamlDumper
+    except ImportError:
+        from yaml import Loader as YamlLoader, Dumper as YamlDumper
+
 # ------------------------------------------------------------------------------------------------------------------------
 # Debug functions
 # ------------------------------------------------------------------------------------------------------------------------
@@ -194,11 +202,11 @@ def decode_yaml(text_or_stream: Union[str, IO]) -> Any:
         When YAML encoder can not be imported.
     """
     require_yaml()
-    return yaml.safe_load(text_or_stream)
+    return yaml.load(text_or_stream, Loader=YamlLoader)
 
 
 # ------------------------------------------------------------------------------------------------------------------------
-def encode_yaml(obj: Any) -> str:
+def encode_yaml(obj: Any, filp: Optional[FileIO] = None) -> str:
     """
     Serialize an object to a YAML-formatted string.
 
@@ -206,6 +214,8 @@ def encode_yaml(obj: Any) -> str:
     ----------
     obj : Any
         The object to be serialized.
+    filp : FileIO, optional
+        A file to write to insetead of returning a string
 
     Returns
     -------
@@ -218,7 +228,10 @@ def encode_yaml(obj: Any) -> str:
         When YAML encoder can not be imported.
     """
     require_yaml()
-    return yaml.safe_dump(obj, explicit_start=True, default_flow_style=False)
+    if filp is not None:
+        return yaml.dump(obj, filp, explicit_start=True, default_flow_style=False, Dumper=YamlDumper)
+    else:
+        return yaml.dump(obj, explicit_start=True, default_flow_style=False, Dumper=YamlDumper)
 
 
 # ------------------------------------------------------------------------------------------------------------------------
@@ -242,3 +255,111 @@ def pretty_yaml(obj: Any) -> str:
         When YAML encoder can not be imported.
     """
     return encode_yaml(obj)
+
+
+# ------------------------------------------------------------------------------------------------------------------------
+def _yaml_auto_represent(dumper: Any, tag: str, data: Any) -> Any:
+    """
+    Automatically represent either a scalar, a sequence, or a mapping.
+
+    Parameters
+    ----------
+    dumper : Any
+        The yaml dumper.
+    tag : str
+        The tag to use for the node.
+    data : Any
+        The data to represent.
+
+    Returns
+    -------
+    Any
+        The result of calling dumper.represent_scalar(tag, data) for scalars,
+        dumper.represent_sequence(tag, data) for sequences, or
+        dumper.represent_mapping(tag, data) for mappings.
+    """
+    require_yaml()
+    from yaml import BaseDumper
+    dumper: BaseDumper = dumper
+
+    if is_sequence(data):
+        return dumper.represent_sequence(tag, data)
+    elif is_mapping(data):
+        return dumper.represent_mapping(tag, data)
+    else:
+        return dumper.represent_scalar(tag, data)
+
+
+# ------------------------------------------------------------------------------------------------------------------------
+def _yaml_auto_construct(loader: Any, node: Any) -> Any:
+    """
+    Automatically construct the appropriate structure based on node type.
+
+    Parameters
+    ----------
+    loader : yaml.BaseLoader
+        The YAML loader object
+    node : yaml.Node
+        The node to construct.
+
+    Returns
+    -------
+    Any
+        The result of calling loader.construct_scalar(node) for scalars,
+        loader.construct_sequence(node) for sequences, or
+        loader.construct_mapping(node) for mappings.
+    """
+    require_yaml()
+    from yaml import SequenceNode, MappingNode, Node, BaseLoader
+    loader: BaseLoader = loader
+    node:   Node       = node
+
+    if isinstance(node, SequenceNode):
+        return loader.construct_sequence(node)
+    elif isinstance(node, MappingNode):
+        return loader.construct_mapping(node)
+    else:
+        return loader.construct_scalar(node)
+
+
+# ------------------------------------------------------------------------------------------------------------------------
+def register_yaml_type(
+    klass:       type,
+    encoder:     Callable[[Any], Any],
+    decoder:     Callable[[Any], Any],
+    key:         Optional[str]     = None,
+    resolver:    Optional[Pattern] = None,
+):
+    """
+    Register a class for YAML loading/dumping.
+
+    Parameters
+    ----------
+    klass : type
+        The class to register.
+    encoder : Callable[[Any], Any]
+        A method which takes an instance of the class and returns either a
+        scalar, a sequence, or a mapping.
+    decoder : Callable[[Any], Any]
+        A method which takes the result of the encoder and instantiates an
+        instance of the class.
+    key : Optional[str], optional
+        YAML tag to use (less leading '!'), by default will be lowercase name of class.
+    resolver : Pattern, optional
+        A regular expression to use to enable implicit construction, by default None.
+        When omitted no implicit resolver will be defined.
+        Note: for large documents, implicit resolvers can seriously degrade performance.
+    """
+    require_yaml()
+    key = key or klass.__name__.lower()
+    tag = f'!{key}'
+    YamlDumper.add_representer(
+        klass,
+        lambda dumper, data: _yaml_auto_represent(dumper, tag, encoder(data))
+    )
+    YamlLoader.add_constructor(
+        tag,
+        lambda loader, node: decoder(_yaml_auto_construct(loader, node))
+    )
+    if resolver:
+        YamlLoader.add_implicit_resolver(tag, resolver)
