@@ -13,7 +13,7 @@ import tempfile
 import errno
 import hashlib
 from typing import Any, Union, Callable, List
-from ptutils.encoding import encode_json, decode_json, encode_yaml, decode_yaml, require_yaml
+from ptutils.encoding import encode_json, decode_json, encode_yaml, decode_yaml
 from ptutils.undefined import UNDEFINED, Undefined, is_undefined
 
 # =======================================================================================================================
@@ -454,9 +454,8 @@ def save_yaml(filename: str, obj: Any) -> None:
         The object to serialize. Must consist of JSON serializable types. See `encode_yaml` for more
         information on how `obj` is encoded.
     """
-    yaml = require_yaml()
     with open(filename, 'w') as filp:
-        yaml.safe_dump(obj, filp, explicit_start=True, default_flow_style=False)
+        encode_yaml(obj, filp)
 
 
 # ------------------------------------------------------------------------------------------------------------------------
