@@ -314,7 +314,7 @@ class Program(object):  # pragma: no cover
             An event used to signal processing should be stopped.
         """
         prefix = (self.log_prefix + ' ') if self.log_prefix else ''
-        while not stopped.isSet():
+        while not stopped.is_set():
             try:
                 (channel, capture, display, line, timestamp) = queue.get_nowait()
                 if line is not None:
