@@ -9,7 +9,7 @@ A collection of functions for text manipulation.
 # =======================================================================================================================
 # Main imports
 # =======================================================================================================================
-from typing import List, Any, Union
+from typing import Dict, List, Any, Union
 from ptutils.encoding import decode_json, decode_yaml
 from ptutils.undefined import is_undefined
 from ptutils.typing import is_string, is_sequence
@@ -279,3 +279,65 @@ def canonize(text: Any) -> Any:
 
     # give up and return the object unmodified.
     return text
+
+
+# -----------------------------------------------------------------------------------------------------------------------
+def maybe_canonize(v: Any, should_canonize: bool = True) -> Any:
+    """
+    Optionally `canonize` a value.
+
+    Parameters
+    ----------
+    v : Any
+        The value to possibly canonize.
+    should_canonize : bool, optional
+        When true, returnb `canonize(v)`, otherwise return `v`, by default True
+
+    Returns
+    -------
+    Any
+        Either `v` or the canonization of `v`.
+    """
+    return canonize(v) if should_canonize else v
+
+
+# -----------------------------------------------------------------------------------------------------------------------
+def maybe_coerce_none(v: Any, should_coerce: bool = True) -> Any:
+    """
+    Optionally coerce falsey values to None.
+
+    Parameters
+    ----------
+    v : Any
+        The value to possibly coerce.
+    should_coerce : bool, optional
+        When true and `v` is falsey, return None. Otherwise return `v`, by default True
+
+    Returns
+    -------
+    Any
+        The value of `v` possibly coerced to None if falsey.
+    """
+    return (v or None) if should_coerce else v
+
+
+# -----------------------------------------------------------------------------------------------------------------------
+def canonize_dict( x: Dict[ str, Any ]) -> Any:
+    """
+    Canonize the values of a dictionary (see `canonize`).
+
+    Parameters
+    ----------
+    x : Dict[ str, Any ]
+        A dictionary.
+
+    Returns
+    -------
+    Any
+        A copy of `x` with values replaced with their canonized equivalents.
+    """
+    return dict(
+        (k, canonize(v))
+        for (k, v)
+        in  x.items()
+    )
