@@ -2,5 +2,5 @@
 # -*- coding: utf-8 -*-
 
 """
-This module defines unit tests for `pt.ptutils.cli`.
+This module defines unit tests for `ptutils.cli`.
 """
