@@ -5,6 +5,7 @@
 
 import pytest
 import datetime
+from typing import Dict, Any
 from ptutils.encoding import (
     HAVE_YAML,
     encode_json,
@@ -13,7 +14,8 @@ from ptutils.encoding import (
     pretty_yaml,
     decode_json,
     decode_yaml,
-    json_serial
+    json_serial,
+    register_yaml_type
 )
 
 
@@ -106,3 +108,49 @@ def test_yaml_pretty_roundtrip(test_case):
         assert decoded_test_case == test_case
     else:
         pytest.skip("No YAML support")
+
+
+def test_yaml_register_type():
+
+    if HAVE_YAML:
+        class T:
+            def __init__(self, data: Dict[str, Any]):
+                self.a = data.get('a', None)
+                self.b = data.get('b', None)
+                self.c = data.get('c', None)
+
+            def to_dict(self) -> Dict[str, Any]:
+                rv = dict()
+                if self.a is not None:
+                    rv['a'] = self.a
+                if self.b is not None:
+                    rv['b'] = self.b
+                if self.c is not None:
+                    rv['c'] = self.c
+                return rv
+
+        def encode_t(t: T) -> Dict[str, Any]:
+            return t.to_dict()
+
+        def decode_t(data: Dict[str, Any]) -> T:
+            return T(data)
+
+        register_yaml_type(T, encode_t, decode_t, key='special')
+
+        t = decode_yaml(
+            '\n'.join([
+                '--- !special',
+                'a: 1',
+                'b: 2'
+            ])
+        )
+        assert isinstance(t, T)
+        assert t.to_dict() == {'a': 1, 'b': 2}
+        assert t.c is None
+
+        t2 = T(data = {'a': 7, 'b': 8, 'c': 9})
+        print(f">>>{encode_yaml(t2)}<<<")
+        assert encode_yaml(t2) == '--- !special\na: 7\nb: 8\nc: 9\n'
+
+    else:
+        pytest.skip("No YAML support")
